summaryrefslogtreecommitdiff
path: root/backend/src/models
diff options
context:
space:
mode:
authorJoe Carstairs <me@joeac.net>2024-09-17 18:10:17 +0100
committerJoe Carstairs <me@joeac.net>2024-09-17 18:11:39 +0100
commit76974785294089965efc3f55b2a08d4089029c52 (patch)
tree67e72c77857d10461a5c84f59967866fd5b4c365 /backend/src/models
parentcd269b3540fb5e3a988c1b59d3763db360b1fb34 (diff)
Adds /budget_update endpoint
Diffstat (limited to 'backend/src/models')
-rw-r--r--backend/src/models/budget_update.rs3
1 files changed, 2 insertions, 1 deletions
diff --git a/backend/src/models/budget_update.rs b/backend/src/models/budget_update.rs
index ea93c16..c63e957 100644
--- a/backend/src/models/budget_update.rs
+++ b/backend/src/models/budget_update.rs
@@ -1,10 +1,11 @@
use diesel::prelude::*;
+use serde::Serialize;
use crate::models::category::Category;
use super::date_time_utc::DateTimeUtc;
#[derive(Clone, Queryable, Identifiable, Selectable, Associations, Debug, PartialEq)]
#[diesel(table_name = crate::schema::budget_updates)]
#[diesel(belongs_to(Category))]
pub struct BudgetUpdate {
@@ -1,10 +1,11 @@
use crate::models::category::Category;
use super::date_time_utc::DateTimeUtc;
-#[derive(Clone, Queryable, Identifiable, Selectable, Associations, Debug, PartialEq)]
+#[derive(Clone, Serialize, Queryable, Identifiable, Selectable, Associations, Debug, PartialEq)]
#[diesel(table_name = crate::schema::budget_updates)]
#[diesel(belongs_to(Category))]